"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const serialize_query_params_1 = require("serialize-query-params");
const useQueryParam_1 = require("./useQueryParam");
const updateUrlQuery_1 = require("./updateUrlQuery");
const QueryParamProvider_1 = require("./QueryParamProvider");
/**
 * Given a query parameter configuration (mapping query param name to { encode, decode }),
 * return an object with the decoded values and a setter for updating them.
 */
exports.useQueryParams = (paramConfigMap) => {
    const { history, location } = React.useContext(QueryParamProvider_1.QueryParamContext);
    // read in the raw query
    const rawQuery = React.useMemo(() => serialize_query_params_1.parse(location.search) || {}, [location.search]);
    // parse each parameter via usQueryParam
    const paramNames = Object.keys(paramConfigMap);
    const decodedValues = {};
    for (const paramName of paramNames) {
        decodedValues[paramName] = useQueryParam_1.useQueryParam(paramName, paramConfigMap[paramName], rawQuery)[0];
    }
    // create a setter for updating multiple query params at once
    const setQuery = React.useCallback((changes, updateType) => {
        // encode as strings for the URL
        const encodedChanges = serialize_query_params_1.encodeQueryParams(paramConfigMap, changes);
        // update the URL
        updateUrlQuery_1.default(encodedChanges, location, history, updateType);
    }, [location]);
    // no longer Partial
    return [decodedValues, setQuery];
};
exports.default = exports.useQueryParams;
